
package MT::Plugin::GoogleAnalyticsWidget;

use strict;
use warnings;

use base qw( MT::Plugin );
use MT;

use Data::Dumper;

use MT::Util qw( start_end_day epoch2ts ts2epoch format_ts );
use XML::Simple;

use lib 'lib';
use Analytics;

use vars qw( $VERSION $plugin );
$VERSION = '0.1419';
$plugin = MT::Plugin::GoogleAnalyticsWidget->new ({
    name        => 'GoogleAnalyticsWidget',
    description => 'Creates a Google Analytics widget in the blog dashboard. This is modified version by Shinichi Nozawa. This widget can be worked on MT4.1 but not on MT4.2. ',
    version     => $VERSION,

    author_name => 'Shinichi Nozawa(Originally, Apperceptive, LLC: http://apperceptive.com/)',
    author_link => 'http://www.nozawashinichi.sakura.ne.jp/usingmt/',
	doc_link => 'http://www.nozawashinichi.sakura.ne.jp/usingmt/2008/08/googleanalyticswidget-for-mt41.html',

    blog_config_template    => 'blog_config.tmpl',
    settings    => MT::PluginSettings->new ([
        [ 'analytics_username', { Default => undef, Scope => 'blog' } ],
        [ 'analytics_password', { Default => undef, Scope => 'blog' } ],
        [ 'analytics_profile_id', { Default => undef, Scope => 'blog' } ],
    ]),

#    init_app    => {
#        'MT::App::CMS'  => \&init_cms,
#    },
#    
#    callbacks   => {
#        'MT::App::CMS::template_source.blog_stats'  => \&blog_stats_source,
#    }
});
MT->add_plugin ($plugin);

sub instance { $plugin }

sub init_registry {
	my $component = shift;
	my $reg ={
		'applications' => {
			'cms' => {
				'blog_stats_tabs' => {
					visit => {
						label => 'Google',
						template => 'blog_stats_visit.tmpl',
						stats => \&init_cms,
					},
				},
			},
		},
		'callbacks' => {
			'MT::App::CMS::template_source.blog_stats' => \&init_cms,
		},
	};
	$component->registry($reg);
}

sub init_cms {
    my $app = shift;
    
    {
        local $SIG{__WARN__} = sub {};
        my $orig_method = \&MT::App::CMS::generate_dashboard_stats;
        *MT::App::CMS::generate_dashboard_stats = sub {
            if (!$orig_method->(@_)) {
                return;
            }
            generate_analytics_stats (@_);
        }
    }
}

sub generate_analytics_stats {
    my $app = shift;
    my ($param) = @_;

    return 1 if (!$app->blog || !$plugin->get_config_value ('analytics_profile_id', 'blog:' . $app->blog->id));
    
    return 1 if (! ( $plugin->get_config_value ('analytics_username', 'blog:' . $app->blog->id) && $plugin->get_config_value ('analytics_password', 'blog:' . $app->blog->id) ) );
    my $cache_time = 60 * 60 * 24; # cache for one day

	$param->{google_analytics_profileID} =$plugin->get_config_value ('analytics_profile_id', 'blog:' . $app->blog->id) ;

    #my $stat_url = $param->{comment_stat_url};
	my $stat_url = $param->{stat_url}->{comment};
    $stat_url =~ s{comment\.xml$}{};

    my $analytics_visits_file = 'google_analytics_visits.xml';
    $param->{analytics_visits_stat_url} = $stat_url . $analytics_visits_file;
    my $analytics_visits_path = File::Spec->catfile ($param->{support_path}, $analytics_visits_file);

    my $analytics_visits_time = ( stat($analytics_visits_path) )[9] if -f $analytics_visits_path;
    
    if (!$analytics_visits_time || ( time - $analytics_visits_time > $cache_time )) {
        my $now = time;
        my $today = start_end_day ( epoch2ts ($app->blog, $now ) );
        my $thirty_days_ago = start_end_day ( epoch2ts ($app->blog, $now - (60 * 60 * 24 * 120)) );
        
        my $a = Analytics->new;
        $a->login ($plugin->get_config_value ('analytics_username', 'blog:' . $app->blog->id), $plugin->get_config_value ('analytics_password', 'blog:' . $app->blog->id));
        my $xml_ref = $a->getReport ($plugin->get_config_value ('analytics_profile_id', 'blog:' . $app->blog->id), format_ts ('%Y%m%d', $thirty_days_ago, $app->blog), format_ts ('%Y%m%d', $today, $app->blog), 'VisitorsOverviewReport');

        my @data = @{$xml_ref->{Report}->{Sparkline}->{VisitorsSparkline}->{PrimaryValue}};
        my $this_day = $thirty_days_ago;
        my %counts = ();
        foreach my $count (@data) {
            $counts{substr ($this_day, 0, 8) . 'T00:00:00'} = $count;
            $this_day = epoch2ts ( $app->blog, ts2epoch ($app->blog, $this_day) + (60 * 60 * 24));
        }
        
        unless ($app->create_dashboard_stats_file ($analytics_visits_path, \%counts)) {
            delete $param->{analytics_visits_stat_url};
        }
    }

    1;
}

#sub blog_stats_source {
#    my ($cb, $app, $tmpl) = @_;
#    return if (!$app->blog || !$plugin->get_config_value ('analytics_profile_id', 'blog:' . $app->blog->id));
#        
#    my $new = q{
#        <div id="analytics-panel" class="<mt:unless name="tab" eq="analytics">hidden</mt:unless>" mt:tab-content="analytics">
#            <mt:if name="analytics_visits_stat_url">
#            <script type="text/javascript">
#            <!--
#            var analyicsSlider = new FlashTag("<mt:var name="static_uri">flash/date_slider_open.swf?date_range="+date_range+"&file_name=<mt:var name="analytics_visits_stat_url">&box_color="+box_color+"&bar_color="+bar_color+"&line_color="+line_color+"&slider_variable=Visits&slider_variable_singular=Visit&lang=<mt:var name="language_tag">&static_path="+escape(StaticURI+"flash"), 540, 122);
#            analyicsSlider.setFlashvars("lcId=" + lcId);
#            analyicsSlider.setFlashvars("flashSource=http://www.measuremap.com/developer/slider/&contentLicense=http://creativecommons.org/licenses/by/2.0/");
#            analyicsSlider.write (document);
#            // -->
#            </script>
#
#            <div class="stats-summary" id="stats-summary-analytics">&nbsp;</div>
#            </mt:if>
#
#        </div>};
#
#    $$tmpl =~ s{(\Q<mt:if name="tag_cloud">
#    <div id="tag-panel" class="<mt:unless name="tab" eq="tag">hidden</mt:unless>" mt:tab-content="tag">
#    \E)}{$new
#$1}m;
#    
#    $$tmpl =~ s{(\Q<mt:if name="tag_cloud">
#        <li id="tag-tab"\E)}{<li id="analytics-tab" class="tab <mt:if name="tab" eq="analytics">selected-tab</mt:if>" mt:tab="analytics" mt:command="select-tab" onclick="return blogStatsTabSelect('analytics');"><a href="javascript:void(0)" ><span><__trans phrase="Visits"></span></a></li>
#$1}m;
#}

1;
